@@ -7,6 +7,7 @@ from tiddlyweb.wikitext import render_wikitext
 from tiddlyweb.serializations.html import Serialization as HTMLSerialization
 from tiddlyweb.web.util import encode_name
 
+from tiddlywebplugins.tiddlyspace.space import Space
 from tiddlywebplugins.tiddlyspace.spaces import space_uri
 
 
@@ -31,7 +32,8 @@ class Serialization(HTMLSerialization):
         space_link = self._space_link(tiddler)
         html = render_wikitext(tiddler, self.environ)
         self.environ['tiddlyweb.title'] = tiddler.title
-        return list_html + space_link + self._tiddler_div(tiddler) + html + '</div>'
+        tiddler_info = self._tiddler_div(tiddler)
+        return list_html + space_link + tiddler_info + html + '</div>'
 
     def _space_link(self, tiddler):
         """
@@ -49,12 +51,14 @@ class Serialization(HTMLSerialization):
             return ''
 
         space_link = """
-<div class="tiddlerslink"><a href="%s%s" title="space link">%s in space</a></div>
+<div class="tiddlerslink">
+<a href="%s%s" title="space link">%s in space</a>
+</div>
 """ % (self._server_prefix(), link, tiddler.title)
         return space_link
 
     def _space_bag(self, bag_name):
-        return bag_name.endswith('_public') or bag_name.endswith('_private')
+        return Space.bag_is_public(bag_name) or Space.bag_is_private(bag_name)
 
     def _encode_space_link(self, tiddler):
         return '/#%%5B%%5B%s%%5D%%5D' % encode_name(tiddler.title)
